package ch.zhaw.projekt2.turnierverwaltung.main;

import ch.zhaw.projekt2.turnierverwaltung.Factory;
import ch.zhaw.projekt2.turnierverwaltung.FactoryDecorator;
import ch.zhaw.projekt2.turnierverwaltung.FileIO;
import ch.zhaw.projekt2.turnierverwaltung.TournamentDecorator;
import javafx.application.Application;
import javafx.event.EventHandler;
import javafx.fxml.FXMLLoader;
import javafx.scene.Scene;
import javafx.scene.layout.BorderPane;
import javafx.stage.Stage;
import javafx.stage.WindowEvent;

import java.util.logging.Logger;


public class MainWindow extends Application {
    private FileIO fileIO = new FileIO(System.getProperty("user.dir") + System.getProperty("file.separator") + "tournierverwaltung_angrynerds");
    private FactoryDecorator factoryDecorator;
    private TournamentDecorator tournamentDecorator = new TournamentDecorator(fileIO);
    private Factory factory = new Factory(fileIO, tournamentDecorator);
    private static final Logger logger = Logger.getLogger(FileIO.class.getCanonicalName());

    @Override
    public void start(Stage primaryStage) throws Exception {
        BorderPane pane = factory.loadMainWindow();
        factoryDecorator = new FactoryDecorator(fileIO, factory, pane);
        factory.loadAllViews(factoryDecorator, pane);
        tournamentDecorator.setFactoryDecorator(factoryDecorator);
        factoryDecorator.openTournamentList();

        Scene scene = new Scene(pane);
        primaryStage.setScene(scene);
        primaryStage.setMaximized(true);
        primaryStage.setResizable(true);
        primaryStage.setFullScreen(false);
        primaryStage.show();
    }

    @Override
    public void stop() {
        try {
            super.stop();
            tournamentDecorator.closeApplication();
        } catch (Exception e) {
            logger.warning("Exception while closing application");
        }
    }
}
